@@ -10,7 +10,7 @@ import requests
 import requests_cache
 from bs4 import BeautifulSoup
 
-cache_enabled = False
+cache_enabled = True
 if cache_enabled:
     print("Cache Enabled")
     requests_cache.install_cache('cache', expire_after=3600)
